@@ -1,7 +1,12 @@
 export {
-  AuthExpiredError,
-  ServerResponseError,
   ServerUnavailableError,
+  ServerResponseError,
+  NotFoundError,
+  AuthError,
+  AuthInvalidError,
+  AuthExpiredError,
+  ForbiddenError,
   VersionIncompatibleError,
+  ResourceConflictError,
 } from './errors';
 export { TamanuApi } from './TamanuApi';
